# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from public_api_server_connector.models.api_key_update import ApiKeyUpdate  # noqa: E501

class TestApiKeyUpdate(unittest.TestCase):
    """ApiKeyUpdate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiKeyUpdate:
        """Test ApiKeyUpdate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiKeyUpdate`
        """
        model = ApiKeyUpdate()  # noqa: E501
        if include_optional:
            return ApiKeyUpdate(
                name = '',
                permissions = {
                    'key' : public_api_server_connector.models.category_permissions.CategoryPermissions(
                        create = True, 
                        read = True, 
                        update = True, 
                        delete = True, )
                    }
            )
        else:
            return ApiKeyUpdate(
                name = '',
        )
        """

    def testApiKeyUpdate(self):
        """Test ApiKeyUpdate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
